@@ -24,6 +24,7 @@
 #include "driver.h"
 #include "messages.h"
 #include "macros.h"
+#include "misc.h"
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -33,7 +34,7 @@
 #include <errno.h>
 #include <time.h>
 
-static int 
+static gboolean
 affile_open_file(gchar *name, int flags,
 	     int uid, int gid, int mode,
 	     int dir_uid, int dir_gid, int dir_mode,
@@ -44,7 +45,7 @@ affile_open_file(gchar *name, int flags,
       msg_error("Spurious path, logfile not created",
                 evt_tag_str("path", name),
                 NULL);
-      return 0;
+      return FALSE;
     }
 
   *fd = open(name, flags, mode);
@@ -61,7 +62,7 @@ affile_open_file(gchar *name, int flags,
 	  if (stat(name, &st) == 0) 
 	    {
 	      if (!S_ISDIR(st.st_mode))
-		return 0;
+		return FALSE;
 	    }
 	  else if (errno == ENOENT) 
 	    {
@@ -192,7 +193,10 @@ affile_dw_init(LogPipe *s, GlobalConfig *cfg, PersistentConfig *persist)
   else
     flags = O_WRONLY | O_CREAT | O_APPEND | O_NOCTTY | O_NONBLOCK;
 
-  if (affile_open_file(self->filename->str, flags, -1, -1, -1, 0, 0, 0, 0, &fd))
+  if (affile_open_file(self->filename->str, flags, 
+                       self->owner->file_uid, self->owner->file_gid, self->owner->file_perm, 
+                       self->owner->dir_uid, self->owner->dir_gid, self->owner->dir_perm, 
+                       !!(self->owner->flags & AFFILE_CREATE_DIRS), &fd))
     {
       self->writer = log_writer_new(LW_FORMAT_FILE, s, &self->owner->writer_options);
         
@@ -375,37 +379,38 @@ affile_dd_set_fsync()
 {
 }
 
+static time_t reap_now = 0;
+
+static gboolean
+affile_dd_reap_writers(gpointer key, gpointer value, gpointer user_data)
+{
+  AFFileDestDriver *self = (AFFileDestDriver *) user_data;
+  AFFileDestWriter *dw = (AFFileDestWriter *) value;
+  
+  if ((reap_now - dw->last_msg_stamp) >= self->time_reap)
+    {
+      msg_verbose("Destination timed out, reaping", 
+                  evt_tag_str("template", self->filename_template->template->str),
+                  evt_tag_str("filename", dw->filename->str),
+                  NULL);
+      log_pipe_deinit(&dw->super, NULL, NULL);
+      log_pipe_unref(&dw->super);
+      
+      /* remove from hash table */
+      return TRUE;
+    }
+  return FALSE;
+}
 
 static gboolean
 affile_dd_reap(gpointer s)
 {
   AFFileDestDriver *self = (AFFileDestDriver *) s;
-  time_t now = time(NULL);
-
-  static gboolean
-  affile_dd_reap_writers(gpointer key, gpointer value, gpointer user_data)
-  {
-    AFFileDestDriver *dd = (AFFileDestDriver *) user_data;
-    AFFileDestWriter *dw = (AFFileDestWriter *) value;
-    
-    if ((now - dw->last_msg_stamp) >= self->time_reap)
-      {
-        msg_verbose("Destination timed out, reaping", 
-                    evt_tag_str("template", dd->filename_template->template->str),
-                    evt_tag_str("filename", dw->filename->str),
-                    NULL);
-        log_pipe_deinit(&dw->super, NULL, NULL);
-        log_pipe_unref(&dw->super);
-        
-        /* remove from hash table */
-        return TRUE;
-      }
-    return FALSE;
-  }
   
   msg_verbose("Reaping unused destination files",
               evt_tag_str("template", self->filename_template->template->str),
               NULL);  
+  reap_now = time(NULL);
   if (self->writer_hash)
     g_hash_table_foreach_remove(self->writer_hash, affile_dd_reap_writers, self);
   return TRUE;
@@ -435,6 +440,8 @@ affile_dd_init(LogPipe *s, GlobalConfig *cfg, PersistentConfig *persist)
     self->dir_perm = cfg->dir_perm;
   if (self->time_reap == -1)
     self->time_reap = cfg->time_reap;
+  
+  self->use_time_recvd = cfg->use_time_recvd;
   log_writer_options_init(&self->writer_options, cfg, FALSE);
   self->cfg = cfg;
   
@@ -507,7 +514,9 @@ affile_dd_queue(LogPipe *s, LogMessage *msg, gint path_flags)
       filename = g_string_sized_new(32);
       log_template_format(self->filename_template, msg, 
 		    ((self->flags & AFFILE_TMPL_ESCAPE) ? MF_ESCAPE_RESULT : 0) |
-		    ((self->flags & AFFILE_STAMP_RECVD) ? MF_STAMP_RECVD : 0),
+		    (self->use_time_recvd ? MF_STAMP_RECVD : 0),
+		    TS_FMT_BSD,
+		    get_local_timezone_ofs(),
 		    filename);
       next = g_hash_table_lookup(self->writer_hash, filename->str);
       if (!next)
@@ -558,6 +567,10 @@ affile_dd_new(gchar *filename, guint32 flags)
   self->filename_template = log_template_new(NULL, filename);
   self->template = g_string_sized_new(0);
   self->flags = flags;
+  self->file_uid = self->file_gid = -1;
+  self->file_perm = -1;
+  self->dir_uid = self->dir_uid = -1;
+  self->dir_perm = -1;
   log_writer_options_defaults(&self->writer_options);
   if (strchr(filename, '$') == NULL)
     {
