@@ -74,49 +74,51 @@
      KW_NO_PARSE = 300,
      KW_PAD_SIZE = 301,
      KW_TIME_ZONE = 302,
-     KW_TIME_REOPEN = 303,
-     KW_TIME_REAP = 304,
-     KW_TMPL_ESCAPE = 305,
-     KW_CREATE_DIRS = 306,
-     KW_OWNER = 307,
-     KW_GROUP = 308,
-     KW_PERM = 309,
-     KW_DIR_OWNER = 310,
-     KW_DIR_GROUP = 311,
-     KW_DIR_PERM = 312,
-     KW_TEMPLATE = 313,
-     KW_TEMPLATE_ESCAPE = 314,
-     KW_FOLLOW_FREQ = 315,
-     KW_KEEP_ALIVE = 316,
-     KW_MAX_CONNECTIONS = 317,
-     KW_LOCALIP = 318,
-     KW_IP = 319,
-     KW_LOCALPORT = 320,
-     KW_PORT = 321,
-     KW_DESTPORT = 322,
-     KW_USE_TIME_RECVD = 323,
-     KW_FACILITY = 324,
-     KW_LEVEL = 325,
-     KW_HOST = 326,
-     KW_MATCH = 327,
-     KW_YES = 328,
-     KW_NO = 329,
-     KW_REQUIRED = 330,
-     KW_ALLOW = 331,
-     KW_DENY = 332,
-     KW_GC_IDLE_THRESHOLD = 333,
-     KW_GC_BUSY_THRESHOLD = 334,
-     KW_COMPRESS = 335,
-     KW_MAC = 336,
-     KW_AUTH = 337,
-     KW_ENCRYPT = 338,
-     DOTDOT = 339,
-     IDENTIFIER = 340,
-     NUMBER = 341,
-     STRING = 342,
-     KW_OR = 343,
-     KW_AND = 344,
-     KW_NOT = 345
+     KW_RECV_TIME_ZONE = 303,
+     KW_SEND_TIME_ZONE = 304,
+     KW_TIME_REOPEN = 305,
+     KW_TIME_REAP = 306,
+     KW_TMPL_ESCAPE = 307,
+     KW_CREATE_DIRS = 308,
+     KW_OWNER = 309,
+     KW_GROUP = 310,
+     KW_PERM = 311,
+     KW_DIR_OWNER = 312,
+     KW_DIR_GROUP = 313,
+     KW_DIR_PERM = 314,
+     KW_TEMPLATE = 315,
+     KW_TEMPLATE_ESCAPE = 316,
+     KW_FOLLOW_FREQ = 317,
+     KW_KEEP_ALIVE = 318,
+     KW_MAX_CONNECTIONS = 319,
+     KW_LOCALIP = 320,
+     KW_IP = 321,
+     KW_LOCALPORT = 322,
+     KW_PORT = 323,
+     KW_DESTPORT = 324,
+     KW_USE_TIME_RECVD = 325,
+     KW_FACILITY = 326,
+     KW_LEVEL = 327,
+     KW_HOST = 328,
+     KW_MATCH = 329,
+     KW_YES = 330,
+     KW_NO = 331,
+     KW_REQUIRED = 332,
+     KW_ALLOW = 333,
+     KW_DENY = 334,
+     KW_GC_IDLE_THRESHOLD = 335,
+     KW_GC_BUSY_THRESHOLD = 336,
+     KW_COMPRESS = 337,
+     KW_MAC = 338,
+     KW_AUTH = 339,
+     KW_ENCRYPT = 340,
+     DOTDOT = 341,
+     IDENTIFIER = 342,
+     NUMBER = 343,
+     STRING = 344,
+     KW_OR = 345,
+     KW_AND = 346,
+     KW_NOT = 347
    };
 #endif
 #define KW_SOURCE 258
@@ -164,55 +166,57 @@
 #define KW_NO_PARSE 300
 #define KW_PAD_SIZE 301
 #define KW_TIME_ZONE 302
-#define KW_TIME_REOPEN 303
-#define KW_TIME_REAP 304
-#define KW_TMPL_ESCAPE 305
-#define KW_CREATE_DIRS 306
-#define KW_OWNER 307
-#define KW_GROUP 308
-#define KW_PERM 309
-#define KW_DIR_OWNER 310
-#define KW_DIR_GROUP 311
-#define KW_DIR_PERM 312
-#define KW_TEMPLATE 313
-#define KW_TEMPLATE_ESCAPE 314
-#define KW_FOLLOW_FREQ 315
-#define KW_KEEP_ALIVE 316
-#define KW_MAX_CONNECTIONS 317
-#define KW_LOCALIP 318
-#define KW_IP 319
-#define KW_LOCALPORT 320
-#define KW_PORT 321
-#define KW_DESTPORT 322
-#define KW_USE_TIME_RECVD 323
-#define KW_FACILITY 324
-#define KW_LEVEL 325
-#define KW_HOST 326
-#define KW_MATCH 327
-#define KW_YES 328
-#define KW_NO 329
-#define KW_REQUIRED 330
-#define KW_ALLOW 331
-#define KW_DENY 332
-#define KW_GC_IDLE_THRESHOLD 333
-#define KW_GC_BUSY_THRESHOLD 334
-#define KW_COMPRESS 335
-#define KW_MAC 336
-#define KW_AUTH 337
-#define KW_ENCRYPT 338
-#define DOTDOT 339
-#define IDENTIFIER 340
-#define NUMBER 341
-#define STRING 342
-#define KW_OR 343
-#define KW_AND 344
-#define KW_NOT 345
+#define KW_RECV_TIME_ZONE 303
+#define KW_SEND_TIME_ZONE 304
+#define KW_TIME_REOPEN 305
+#define KW_TIME_REAP 306
+#define KW_TMPL_ESCAPE 307
+#define KW_CREATE_DIRS 308
+#define KW_OWNER 309
+#define KW_GROUP 310
+#define KW_PERM 311
+#define KW_DIR_OWNER 312
+#define KW_DIR_GROUP 313
+#define KW_DIR_PERM 314
+#define KW_TEMPLATE 315
+#define KW_TEMPLATE_ESCAPE 316
+#define KW_FOLLOW_FREQ 317
+#define KW_KEEP_ALIVE 318
+#define KW_MAX_CONNECTIONS 319
+#define KW_LOCALIP 320
+#define KW_IP 321
+#define KW_LOCALPORT 322
+#define KW_PORT 323
+#define KW_DESTPORT 324
+#define KW_USE_TIME_RECVD 325
+#define KW_FACILITY 326
+#define KW_LEVEL 327
+#define KW_HOST 328
+#define KW_MATCH 329
+#define KW_YES 330
+#define KW_NO 331
+#define KW_REQUIRED 332
+#define KW_ALLOW 333
+#define KW_DENY 334
+#define KW_GC_IDLE_THRESHOLD 335
+#define KW_GC_BUSY_THRESHOLD 336
+#define KW_COMPRESS 337
+#define KW_MAC 338
+#define KW_AUTH 339
+#define KW_ENCRYPT 340
+#define DOTDOT 341
+#define IDENTIFIER 342
+#define NUMBER 343
+#define STRING 344
+#define KW_OR 345
+#define KW_AND 346
+#define KW_NOT 347
 
 
 
 
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
-#line 39 "/home/bazsi/zwa/work/syslog-ng-2.0/syslog-ng/src/cfg-grammar.y"
+#line 40 "/home/bazsi/zwa/work/syslog-ng-2.0/syslog-ng/src/cfg-grammar.y"
 typedef union YYSTYPE {
 	guint num;
 	char *cptr;
@@ -220,7 +224,7 @@ typedef union YYSTYPE {
 	FilterExprNode *node;
 } YYSTYPE;
 /* Line 1285 of yacc.c.  */
-#line 224 "y.tab.h"
+#line 228 "y.tab.h"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
