@@ -47,6 +47,7 @@ macros[] =
         { "DATE", M_DATE },
         { "FULLDATE", M_FULLDATE },
         { "ISODATE", M_ISODATE },
+        { "STAMP", M_STAMP },
         { "YEAR", M_YEAR },
         { "MONTH", M_MONTH },
         { "DAY", M_DAY },
@@ -54,6 +55,7 @@ macros[] =
         { "MIN", M_MIN },
         { "SEC", M_SEC },
         { "WEEKDAY", M_WEEKDAY },
+        { "WEEK", M_WEEK },
         { "UNIXTIME", M_UNIXTIME },
         { "TZOFFSET", M_TZOFFSET },
         { "TZ", M_TZ },
@@ -61,6 +63,7 @@ macros[] =
         { "R_DATE", M_DATE_RECVD },
         { "R_FULLDATE", M_FULLDATE_RECVD },
         { "R_ISODATE", M_ISODATE_RECVD },
+        { "R_STAMP", M_STAMP_RECVD },
         { "R_YEAR", M_YEAR_RECVD },
         { "R_MONTH", M_MONTH_RECVD },
         { "R_DAY", M_DAY_RECVD },
@@ -68,6 +71,7 @@ macros[] =
         { "R_MIN", M_MIN_RECVD },
         { "R_SEC", M_SEC_RECVD },
         { "R_WEEKDAY", M_WEEKDAY_RECVD },
+        { "R_WEEK", M_WEEK_RECVD },
         { "R_UNIXTIME", M_UNIXTIME_RECVD },
         { "R_TZOFFSET", M_TZOFFSET_RECVD },
         { "R_TZ", M_TZ_RECVD },
@@ -75,6 +79,7 @@ macros[] =
         { "S_DATE", M_DATE_STAMP },
         { "S_FULLDATE", M_FULLDATE_STAMP },
         { "S_ISODATE", M_ISODATE_STAMP },
+        { "S_STAMP", M_STAMP_STAMP },
         { "S_YEAR", M_YEAR_STAMP },
         { "S_MONTH", M_MONTH_STAMP },
         { "S_DAY", M_DAY_STAMP },
@@ -82,6 +87,7 @@ macros[] =
         { "S_MIN", M_MIN_STAMP },
         { "S_SEC", M_SEC_STAMP },
         { "S_WEEKDAY", M_WEEKDAY_STAMP },
+        { "S_WEEK", M_WEEK_STAMP },
         { "S_UNIXTIME", M_UNIXTIME_STAMP },
         { "S_TZOFFSET", M_TZOFFSET_STAMP },
         { "S_TZ", M_TZ_STAMP },
@@ -128,7 +134,7 @@ result_append(GString *result, gchar *str, gint len, gboolean escape)
 }
 
 gboolean
-log_macro_expand(GString *result, gint id, guint32 flags, glong zone_offset, LogMessage *msg)
+log_macro_expand(GString *result, gint id, guint32 flags, gint ts_format, glong zone_offset, LogMessage *msg)
 {
   if (id >= M_MATCH_REF_OFS)
     {
@@ -218,7 +224,9 @@ log_macro_expand(GString *result, gint id, guint32 flags, glong zone_offset, Log
       }
     case M_FULLDATE:
     case M_ISODATE:
+    case M_STAMP:
     case M_WEEKDAY:
+    case M_WEEK:
     case M_DATE:
     case M_YEAR:
     case M_MONTH:
@@ -232,7 +240,9 @@ log_macro_expand(GString *result, gint id, guint32 flags, glong zone_offset, Log
 
     case M_FULLDATE_RECVD:
     case M_ISODATE_RECVD:
+    case M_STAMP_RECVD:
     case M_WEEKDAY_RECVD:
+    case M_WEEK_RECVD:
     case M_DATE_RECVD:
     case M_YEAR_RECVD:
     case M_MONTH_RECVD:
@@ -246,7 +256,9 @@ log_macro_expand(GString *result, gint id, guint32 flags, glong zone_offset, Log
 
     case M_FULLDATE_STAMP:
     case M_ISODATE_STAMP:
+    case M_STAMP_STAMP:
     case M_WEEKDAY_STAMP:
+    case M_WEEK_STAMP:
     case M_DATE_STAMP:
     case M_YEAR_STAMP:
     case M_MONTH_STAMP:
@@ -263,25 +275,32 @@ log_macro_expand(GString *result, gint id, guint32 flags, glong zone_offset, Log
         gchar buf[64];
         gint length;
         time_t t;
+        LogStamp *stamp;
 
         if (id >= M_FULLDATE_RECVD && id <= M_UNIXTIME_RECVD)
           {
-            t = msg->recvd.time.tv_sec - zone_offset;
+            stamp = &msg->recvd;
             id = id - (M_FULLDATE_RECVD - M_FULLDATE);
           }
         else if (id >= M_FULLDATE_STAMP && id <= M_UNIXTIME_STAMP)
           {
-            t = msg->stamp.time.tv_sec - zone_offset;
+            stamp = &msg->stamp;
             id = id - (M_FULLDATE_STAMP - M_FULLDATE);
           }
         else
           {
             if (flags & MF_STAMP_RECVD)
-              t = msg->recvd.time.tv_sec - zone_offset;
+              stamp = &msg->recvd;
             else
-              t = msg->stamp.time.tv_sec - zone_offset;
+              stamp = &msg->stamp;
           }
-          
+
+        /* try to use the following zone values in order:
+         *   destination specific timezone, if one is specified
+         *   message specific timezone, if one is specified
+         *   local timezone
+         */
+        t = stamp->time.tv_sec - (zone_offset != -1 ? zone_offset : (stamp->zone_offset != -1 ? stamp->zone_offset : get_local_timezone_ofs()));
         tm = gmtime(&t);
 
         switch (id)
@@ -290,6 +309,10 @@ log_macro_expand(GString *result, gint id, guint32 flags, glong zone_offset, Log
             length = strftime(buf, sizeof(buf), "%a", tm);
             g_string_append_len(result, buf, length);
             break;
+          case M_WEEK:
+            length = strftime(buf, sizeof(buf), "%W", tm);
+            g_string_append_len(result, buf, length);
+            break;
           case M_YEAR:
             g_string_sprintfa(result, "%04d", tm->tm_year + 1900);
             break;
@@ -316,6 +339,15 @@ log_macro_expand(GString *result, gint id, guint32 flags, glong zone_offset, Log
             length = strftime(buf, sizeof(buf), "%Y %h %e %H:%M:%S", tm);
             g_string_append_len(result, buf, length);
             break;
+          case M_STAMP:
+            {
+              GString *s = g_string_sized_new(0);
+              
+              log_stamp_format(stamp, s, ts_format, zone_offset);
+              g_string_append_len(result, s->str, s->len);
+              g_string_free(s, TRUE);
+              break;
+            }
           case M_DATE:
             g_string_append_len(result, msg->date->str, msg->date->len);
             break;
@@ -352,7 +384,7 @@ log_macro_expand(GString *result, gint id, guint32 flags, glong zone_offset, Log
             colon++;
             while (*colon && *colon == ' ')
               colon++;
-            
+            ofs = colon - msg->msg->str;
           }
         result_append(result, msg->msg->str + ofs, msg->msg->len - ofs, !!(flags & MF_ESCAPE_RESULT));
         break;
