@@ -34,6 +34,7 @@
 #include <pwd.h>
 #include <grp.h>
 #include <stdlib.h>
+#include <time.h>
 
 GString *
 g_string_assign_len(GString *s, gchar *val, gint len)
@@ -57,6 +58,28 @@ getshorthostname(char *buf, size_t bufsize)
   return buf;
 }
 
+char *
+getlonghostname(char *buf, size_t bufsize)
+{
+  gethostname(buf, bufsize - 1);
+  if (strchr(buf, '.') == NULL)
+    {
+      struct hostent *result = gethostbyname(buf);
+      if (result)
+        {
+          strncpy(buf, result->h_name, bufsize - 1);
+          buf[bufsize - 1] = 0;
+        }
+    }
+  return buf;
+}
+
+long
+get_local_timezone_ofs(void)
+{
+  return timezone - (daylight > 0 ? 3600 : 0);
+}
+
 GString *
 resolve_hostname(GSockAddr *saddr,
 		 int usedns, int usefqdn)
@@ -98,7 +121,10 @@ resolve_hostname(GSockAddr *saddr,
     {
       if (!local_hostname[0]) 
 	{
-	  getshorthostname(local_hostname, sizeof(local_hostname));
+          if (usefqdn)
+            getlonghostname(local_hostname, sizeof(local_hostname));
+          else
+	    getshorthostname(local_hostname, sizeof(local_hostname));
 	}
 
       hname = local_hostname;
