@@ -32,7 +32,9 @@
 
 GString *g_string_assign_len(GString *s, gchar *val, gint len);
 
+char *getlonghostname(char *buf, size_t buflen);
 char *getshorthostname(char *buf, size_t buflen);
+long get_local_timezone_ofs(void);
 GString *resolve_hostname(GSockAddr *saddr, int usedns, int usefqdn);
 gboolean g_fd_set_nonblock(int fd, gboolean enable);
 
