@@ -60,6 +60,7 @@ log_template_compile(LogTemplate *self)
           if (*p >= '0' && *p <= '9')
             {
               last_macro = M_MATCH_REF_OFS + (*p - '0');
+              p++;
             }
           else if (*p == '{')
             {
@@ -111,7 +112,7 @@ log_template_compile(LogTemplate *self)
 }
 
 void
-log_template_format(LogTemplate *self, LogMessage *lm, guint macro_flags, GString *result)
+log_template_format(LogTemplate *self, LogMessage *lm, guint macro_flags, gint ts_format, glong zone_offset, GString *result)
 {
   GList *p;
   LogTemplateElem *e;
@@ -131,7 +132,8 @@ log_template_format(LogTemplate *self, LogMessage *lm, guint macro_flags, GStrin
           log_macro_expand(result, e->macro, 
                            macro_flags |
                            ((self->flags & LT_ESCAPE) ? MF_ESCAPE_RESULT : 0),
-                           (self->flags & LT_TZ_SET) ? self->zone_offset : timezone,
+                           ts_format,
+                           zone_offset,
                            lm);
         }
     }
